#ifndef UU_UNPACK_H
#define UU_UNPACK_H

#include "uulib/UUID.h"

void uu_unpack(const uu_t in, struct uu *out);

#endif
/* ex:set ts=2 sw=2 itab=spaces: */
